Documentation
¶
Index ¶
- type Ctx
- func (c *Ctx) GetMerchantID(resolver identity.IdentityResolver, merchantPublicID string) (merchantID uint64, err *resPkg.Status)
- func (c *Ctx) GetOutletID(resolver identity.IdentityResolver, outletPublicID string) (outletID uint64, err *resPkg.Status)
- func (c *Ctx) Lang() *lang.Lang
- func (c *Ctx) Log() *logCtx.Log
- func (c *Ctx) UserClaims() *jwt.AuthClaims
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Ctx ¶
func (*Ctx) GetMerchantID ¶
func (c *Ctx) GetMerchantID(resolver identity.IdentityResolver, merchantPublicID string) (merchantID uint64, err *resPkg.Status)
GetMerchantID gets the merchant ID by merchant public ID, and check if user has access to it
func (*Ctx) GetOutletID ¶
func (c *Ctx) GetOutletID(resolver identity.IdentityResolver, outletPublicID string) (outletID uint64, err *resPkg.Status)
GetOutletID gets the outlet ID by outlet public ID, and check if user has access to it
func (*Ctx) UserClaims ¶
func (c *Ctx) UserClaims() *jwt.AuthClaims
Click to show internal directories.
Click to hide internal directories.